@@ -654,7 +654,7 @@ class ShareFuture:
             )
 
             if future is None:
-                TypeError(r'Not Coroutine Object')
+                raise TypeError(r'Not Coroutine Object')
 
             self._future[_func_sign] = [future]
 
