@@ -21,7 +21,7 @@ class _BufferAbstract:
             self._do_consume_task()
         )
 
-    async def _do_consume_task(self, data):
+    async def _do_consume_task(self):
         raise NotImplementedError()
 
     def cancel(self):
@@ -92,7 +92,7 @@ class DataQueue(_BufferAbstract):
             self._tasks.remove(task)
 
         if self._wait_future is not None and self._wait_future.done() is False:
-            self._wait_future.set_result()
+            self._wait_future.set_result(None)
 
     def size(self):
 
