@@ -4,11 +4,11 @@ __author__ = r'wsb310@gmail.com'
 
 from .base import Utils, AsyncCirculatorForSecond, FuncWrapper, FutureWithTimeout
 
-from ..event import EventDispatcher
+from ..event import EventDispatcher as _EventDispatcher
 from ..error import catch_error
 
 
-class EventDispatcher(EventDispatcher):
+class EventDispatcher(_EventDispatcher):
     """支持异步函数的事件总线
     """
 
@@ -53,7 +53,7 @@ class DistributedEvent(EventDispatcher):
                         if message:
                             await self._event_assigner(message)
 
-                receiver.close()
+                await receiver.close()
 
     async def _event_assigner(self, message):
 
