@@ -2,7 +2,6 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from ..base import Utils
 from ..cache import StackCache
 from ..error import catch_error
 
@@ -44,7 +43,7 @@ class FileLoader:
 
         return result
 
-    async def fetch(self, url, params=None, cookies=None, headers=None):
+    async def fetch(self, url, params=None, *, cookies=None, headers=None):
 
         result = None
 
@@ -56,7 +55,7 @@ class FileLoader:
 
             else:
 
-                result = await self._http_client.get(url, params, cookies, headers)
+                result = await self._http_client.get(url, params, cookies=cookies, headers=headers)
 
                 self._cache.set(url, result)
 
