@@ -258,14 +258,14 @@ class _ClientBase:
     """
 
     @staticmethod
-    def safestr(val):
+    def safestr(val, charset=r'utf-8'):
 
         cls = type(val)
 
         if cls is str:
             val = aiomysql.escape_string(val)
         elif cls is dict:
-            val = aiomysql.escape_dict(val)
+            val = aiomysql.escape_dict(val, charset)
         else:
             val = str(val)
 
@@ -318,7 +318,7 @@ class _ClientBase:
             else:
                 await _conn.close()
 
-    async def _execute(self, clause):
+    async def _execute(self, clause, *multiparams, **params):
 
         raise NotImplementedError()
 
