@@ -16,48 +16,16 @@ REDIS_ERROR_RETRY_COUNT = 0x10
 REDIS_POOL_WATER_LEVEL_WARNING_LINE = 0x10
 
 
-class _LockMixin(AsyncContextManager):
-
-    __slots__ = [r'_locked']
+class LuaLock(AsyncContextManager, lock.LuaLock):
 
     async def _context_release(self):
-
         await self.release()
 
-    @property
-    def locked(self):
 
-        return self._locked
+class ClusterLock(AsyncContextManager, lock.ClusterLock):
 
-    async def acquire(self, blocking=None, blocking_timeout=None):
-
-        if not self._locked:
-            self._locked = await super().acquire(blocking, blocking_timeout)
-
-        return self._locked
-
-    async def release(self):
-
-        if self._locked:
-            await super().release()
-
-
-class LuaLock(_LockMixin, lock.LuaLock):
-
-    def __init__(self, *args, **kwargs):
-
-        lock.LuaLock.__init__(self, *args, **kwargs)
-        
-        self._locked = False
-
-
-class ClusterLock(_LockMixin, lock.ClusterLock):
-
-    def __init__(self, *args, **kwargs):
-
-        lock.ClusterLock.__init__(self, *args, **kwargs)
-
-        self._locked = False
+    async def _context_release(self):
+        await self.release()
 
 
 class _PoolMixin(AsyncContextManager):
@@ -68,8 +36,6 @@ class _PoolMixin(AsyncContextManager):
         self._key_prefix = None
         self._min_connections = min_connections if min_connections else 0
 
-        LuaLock.register_scripts(self)
-
     async def _context_release(self):
 
         pass
@@ -106,10 +72,6 @@ class _PoolMixin(AsyncContextManager):
         self.connection_pool.disconnect()
         self.connection_pool.reset()
 
-    def allocate_lock(self, name, *, timeout=600, blocking_timeout=0):
-
-        return self.lock(name, timeout=timeout, blocking_timeout=blocking_timeout, lock_class=LuaLock)
-
     async def get_obj(self, name):
 
         result = await super().get(name)
@@ -184,6 +146,10 @@ class StrictRedisPool(_PoolMixin, StrictRedis):
 
         return self.connection_pool._created_connections
 
+    def allocate_lock(self, name, *, timeout=600, blocking_timeout=0):
+
+        return self.lock(name, timeout=timeout, blocking_timeout=blocking_timeout, lock_class=LuaLock)
+
 
 class StrictRedisClusterPool(_PoolMixin, StrictRedisCluster):
     """StrictRedisCluster连接管理
@@ -240,7 +206,7 @@ class StrictRedisClusterPool(_PoolMixin, StrictRedisCluster):
 
         return sum(self.connection_pool._created_connections_per_node.values())
 
-    def allocate_cluster_lock(self, name, *, timeout=60, blocking_timeout=0):
+    def allocate_lock(self, name, *, timeout=60, blocking_timeout=0):
 
         return self.lock(name, timeout=timeout, blocking_timeout=blocking_timeout, lock_class=ClusterLock)
 
