@@ -58,11 +58,11 @@ class Utils:
 
     """
 
-    _BYTES_TYPES = (bytes, type(None))
+    _BYTES_TYPES = (bytes, type(None),)
 
-    _STRING_TYPES = (str, type(None))
+    _STRING_TYPES = (str, type(None),)
 
-    _FALSE_VALUES = {r'null', r'none', r'nil', r'false', r'0', r'', False, 0}
+    _FALSE_VALUES = (r'null', r'none', r'nil', r'false', r'0', r'', False, 0,)
 
     math = math
     random = random
@@ -287,13 +287,13 @@ class Utils:
 
         for item in iterable:
 
-            cls = type(item)
+            _type = type(item)
 
-            if cls is float:
+            if _type is float:
 
                 result.append(str(item))
 
-            elif cls is str:
+            elif _type is str:
 
                 item = item.strip()
 
@@ -321,13 +321,13 @@ class Utils:
 
         for item in iterable:
 
-            cls = type(item)
+            _type = type(item)
 
-            if cls is int:
+            if _type is int:
 
                 result.append(str(item))
 
-            elif cls is str:
+            elif _type is str:
 
                 item = item.strip()
 
