@@ -2,7 +2,8 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from hagworm.extend.base import catch_error, Utils
+from .base import Utils
+from .error import catch_error
 
 
 class M3U8:
