@@ -26,7 +26,7 @@ DEFAULT_LOG_CONFIG = {
     },
     'handlers': {
         'loguru': {
-            'class': 'hagworm.extend.logging.LogInterceptor',
+            'class': 'hagworm.extend.logging.InterceptHandler',
         },
     },
 }
@@ -45,7 +45,7 @@ SIMPLE_LOG_CONFIG = {
     },
     'handlers': {
         'loguru': {
-            'class': 'hagworm.extend.logging.LogInterceptor',
+            'class': 'hagworm.extend.logging.InterceptHandler',
         },
     },
 }
