@@ -13,8 +13,8 @@ class RabbitMQConsumer(aio_pika.RobustConnection):
 
         super().__init__(url, **kwargs)
 
-        self._channel = None
-        self._queue = None
+        self._channel: aio_pika.abc.AbstractRobustChannel = None
+        self._queue: aio_pika.abc.AbstractRobustQueue = None
 
         self._channel_qos_config = None
 
@@ -25,12 +25,17 @@ class RabbitMQConsumer(aio_pika.RobustConnection):
         self._consume_no_ack = None
 
     @property
-    def current_channel(self):
+    def queue_name(self):
+
+        return self._queue_name
+
+    @property
+    def current_channel(self) -> aio_pika.abc.AbstractRobustChannel:
 
         return self._channel
 
     @property
-    def current_queue(self):
+    def current_queue(self) -> aio_pika.abc.AbstractRobustQueue:
 
         return self._queue
 
@@ -47,11 +52,11 @@ class RabbitMQConsumer(aio_pika.RobustConnection):
         self._consume_func = consume_func
         self._consume_no_ack = consume_no_ack
 
-    async def connect(self, *args, **kwargs) -> None:
+    async def connect(self, timeout: aio_pika.abc.TimeoutType = None) -> None:
 
         self._RobustConnection__channels.clear()
 
-        await super().connect(*args, **kwargs)
+        await super().connect(timeout)
         await self.ready()
 
         self._channel = await self.channel()
@@ -81,13 +86,13 @@ class RabbitMQConsumerForExchange(RabbitMQConsumer):
         
         super().__init__(url, **kwargs)
 
-        self._exchange = None
+        self._exchange: aio_pika.abc.AbstractExchange = None
 
         self._exchange_name = None
         self._routing_key = None
 
     @property
-    def current_exchange(self):
+    def current_exchange(self) -> aio_pika.abc.AbstractExchange:
 
         return self._exchange
 
@@ -111,11 +116,11 @@ class RabbitMQConsumerForExchange(RabbitMQConsumer):
         self._exchange_name = exchange_name
         self._routing_key = routing_key
 
-    async def connect(self, *args, **kwargs) -> None:
+    async def connect(self, timeout: aio_pika.abc.TimeoutType = None) -> None:
 
         self._exchange = None
 
-        await super().connect(*args, **kwargs)
+        await super().connect(timeout)
 
         self._exchange = await self._channel.get_exchange(self._exchange_name)
 
